********************
0.1.0a2 - 2021-02-24
********************

Alpha release for testing. The API and the schema for YAML files have been
largely agreed upon. Backwards-incompatible changes before the first stable
release are still possible, but are considered unlikely.

********************
0.1.0a1 - 2020-11-12
********************

Initial alpha release to reserve the name 'demes' on pypi.
